package net.knarcraft.permissionsigns.manager;

import net.milkbowl.vault.economy.Economy;
import org.bukkit.OfflinePlayer;
import org.bukkit.entity.Player;
import org.jetbrains.annotations.NotNull;

/**
 * A manager that performs all Economy tasks
 */
public final class EconomyManager {

    private static Economy economy;

    private EconomyManager() {

    }

    /**
     * Initializes the economy manager
     *
     * @param economy <p>The economy object to use for everything economy-related</p>
     */
    public static void initialize(@NotNull Economy economy) {
        EconomyManager.economy = economy;
    }

    /**
     * Checks whether the given player can afford the given cost
     *
     * @param player <p>The player to pay the cost</p>
     * @param cost   <p>The cost the player needs to pay</p>
     * @return <p>True if the player is able to afford the cost</p>
     */
    public static boolean canAfford(@NotNull OfflinePlayer player, double cost) {
        return economy.has(player, cost);
    }

    /**
     * Formats the given amount of currency according to the used economy plugin
     *
     * @param amount <p>The amount of currency to format</p>
     * @return <p>The formatted amount of currency</p>
     */
    public static String format(double amount) {
        return economy.format(amount);
    }

    /**
     * Withdraws the given cost from the given player's account
     *
     * @param player <p>The player to withdraw money from</p>
     * @param cost   <p>The amount of money to withdraw</p>
     */
    public static void withdraw(@NotNull Player player, double cost) {
        economy.withdrawPlayer(player, cost);
    }

}
